Mesh

Struct Mesh 

pub struct Mesh(/* private fields */);

Implementations

Source

impl Mesh

pub unsafe fn unwrap(self) -> Mesh

Take the raw ffi type. Must manually free memory by calling the proper unload function

Source

impl Mesh

pub fn to_raw(self) -> Mesh

returns the unwrapped raylib-sys object

pub unsafe fn from_raw(raw: Mesh) -> Mesh

converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.

Source

impl Mesh

pub unsafe fn make_weak(self) -> WeakMesh