Texture2D

Struct Texture2D 

pub struct Texture2D(/* private fields */);

Implementations

Source

impl Texture2D

pub unsafe fn unwrap(self) -> Texture

Take the raw ffi type. Must manually free memory by calling the proper unload function

Source

impl Texture2D

pub fn to_raw(self) -> Texture

returns the unwrapped raylib-sys object

pub unsafe fn from_raw(raw: Texture) -> Texture2D

converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.

Source

impl Texture2D

pub unsafe fn make_weak(self) -> WeakTexture2D