pub struct RenderTexture2D(/* private fields */);Implementations
Sourceimpl RenderTexture2D
impl RenderTexture2D
Sourcepub unsafe fn unwrap(self) -> RenderTexture
pub unsafe fn unwrap(self) -> RenderTexture
Take the raw ffi type. Must manually free memory by calling the proper unload function
Sourceimpl RenderTexture2D
impl RenderTexture2D
Sourcepub fn to_raw(self) -> RenderTexture
pub fn to_raw(self) -> RenderTexture
returns the unwrapped raylib-sys object
Sourcepub unsafe fn from_raw(raw: RenderTexture) -> RenderTexture2D
pub unsafe fn from_raw(raw: RenderTexture) -> RenderTexture2D
converts raylib-sys object to a “safe” version. Make sure to call this function from the thread the resource was created.
Sourceimpl RenderTexture2D
impl RenderTexture2D
pub unsafe fn make_weak(self) -> WeakRenderTexture2D